package at.fhstp.dgruenberger.finishedexample

import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.material.Button
import androidx.compose.material.MaterialTheme
import androidx.compose.material.Text
import androidx.compose.material.TextField
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Modifier
import androidx.compose.ui.unit.dp
import org.jetbrains.compose.ui.tooling.preview.Preview
import kotlin.uuid.ExperimentalUuidApi
import kotlin.uuid.Uuid

@OptIn(ExperimentalUuidApi::class)
@Composable
@Preview
fun App(noteStore: NoteStore) {
    MaterialTheme {
        val greeting = remember { Greeting().greet() }
        var noteContent by remember { mutableStateOf("") }
        var notes by remember { mutableStateOf(noteStore.loadNotes()) }

        Column(modifier = Modifier.padding(16.dp)) {
            Text("Compose: $greeting", modifier = Modifier.padding(8.dp))

            TextField(
                value = noteContent,
                onValueChange = { noteContent = it },
                label = { Text("Neue Notiz") },
                modifier = Modifier.fillMaxWidth()
            )
            Spacer(modifier = Modifier.height(8.dp))

            Button(
                onClick = {
                    val newNotes = notes.addNote(noteContent)
                    noteStore.saveNotes(newNotes)
                    noteContent = ""
                    notes = newNotes
                }
            ) {
                Text("Hinzufügen")
            }

            Spacer(modifier = Modifier.height(16.dp))

            notes.map {
                Text(text = it.text, modifier = Modifier.padding(8.dp))
            }
        }
    }
}

@OptIn(ExperimentalUuidApi::class)
private fun List<Note>.addNote(text: String): List<Note> {
    val newNotes = this.toMutableList()
    newNotes.add(Note(id = Uuid.random().toString(), text = text))
    return newNotes
}